/**
 * js logic specific to scrolling menu with arrow elements
 */

const moveStartSpeed = 2;
const speedMultiplier = 1.1;
const intervalTime = 50;
const arrowLeftSelector = ".c-control--arrow-left";
const arrowRightSelector = ".c-control--arrow-right";
const headerNavListSelector = ".c-header-nav__bar__list";

let arrowLeft;
let arrowRight;
let headerNavList;
let moveSpeed = moveStartSpeed;
let scrollInterval;

/**
 * @method init
 * @description init method, adds event listener for scroll and resize
 * @return void
 */
export default function init() {
  headerNavList = document.querySelector(headerNavListSelector);
  arrowLeft = document.querySelector(arrowLeftSelector);
  arrowRight = document.querySelector(arrowRightSelector);

  // scrolling menu event handlers
  arrowLeft.addEventListener("mousedown", () => {
    cancelInterval();
    scrollInterval = setInterval(scrollMenuLeft, intervalTime);
  });

  arrowLeft.addEventListener("mouseup", cancelInterval);

  arrowRight.addEventListener("mousedown", () => {
    cancelInterval();
    scrollInterval = setInterval(scrollMenuRight, intervalTime);
  });

  arrowRight.addEventListener("mouseup", cancelInterval);
}

/**
 * @method scrollMenuLeft
 * @description the speed increases the longer you hold the button
 * @return void
 */
function scrollMenuLeft() {
  moveSpeed *= speedMultiplier;
  headerNavList.scrollLeft += moveSpeed;
}

/**
 * @method scrollMenuRight
 * @description the speed increases the longer you hold the button
 * @return void
 */
function scrollMenuRight() {
  moveSpeed *= speedMultiplier;
  headerNavList.scrollLeft -= moveSpeed;
}

/**
 * @method cancelInterval
 * @description cancels interval for scrolling
 * @return void
 */
function cancelInterval() {
  moveSpeed = moveStartSpeed;
  clearInterval(scrollInterval);
}

