/**
 * js logic for sticky header
 */

const _ = require("lodash");
const headerNavSelector = ".c-header-nav";
const headerNavFixedClass = "c-header-nav--fixed";

let headerNav;
let pinned = false;
let distance;

/**
 * @method init
 * @description init method, adds event listener for scroll and resize
 * @return void
 */
export default function init() {
  headerNav = document.querySelector(headerNavSelector);

  // sticky scrolling logic
  let originalScrollValue = window.pageYOffset;

  window.scrollTo(0, 0);
  distance = headerNav.offsetTop - window.pageYOffset;
  window.scrollTo(0, originalScrollValue);

  // throttled event handlers
  window.addEventListener("scroll", _.throttle(onViewPortChange, 50));
  window.addEventListener("resize", _.throttle(onViewPortChange, 50));

  // run once on initialize
  onViewPortChange();
}

/**
 * @method onViewPortChange
 * @description method checks page scroll offset and applies toggles a class on/off
 * @return void
 */
function onViewPortChange() {
  const isFixed = headerNav.classList.contains(headerNavFixedClass);

  if (window.pageYOffset >= distance && !isFixed && !pinned) {
    pinned = true;
    headerNav.classList.add(headerNavFixedClass);
  } else if (window.pageYOffset <= distance && pinned) {
    pinned = false;
    headerNav.classList.remove(headerNavFixedClass);
  }
}


